import * as React from 'react';
import classNames from 'classnames';
import { toJSON } from './fetchOpenAPIOperation';
import { Markdown } from './Markdown';
import { OpenAPICodeSample } from './OpenAPICodeSample';
import { OpenAPIResponseExample } from './OpenAPIResponseExample';
import { OpenAPIServerURL } from './OpenAPIServerURL';
import { OpenAPISpec } from './OpenAPISpec';
import { ApiClientModalProvider } from '@scalar/api-client-react';
/**
 * Display an interactive OpenAPI operation.
 */
export function OpenAPIOperation(props) {
    const { className, data, context } = props;
    const { operation, servers, method, path } = data;
    const clientContext = {
        defaultInteractiveOpened: context.defaultInteractiveOpened,
        specUrl: context.specUrl,
        icons: context.icons,
    };
    return (React.createElement(ApiClientModalProvider, { configuration: { spec: { url: context.specUrl } }, initialRequest: { path: data.path, method: data.method } },
        React.createElement("div", { className: classNames('openapi-operation', className) },
            React.createElement("div", { className: "openapi-intro" },
                React.createElement("h2", { className: "openapi-summary" }, operation.summary),
                operation.description ? (React.createElement(Markdown, { className: "openapi-description", source: operation.description })) : null,
                React.createElement("div", { className: "openapi-target" },
                    React.createElement("span", { className: classNames('openapi-method', `openapi-method-${method.toLowerCase()}`) }, method.toUpperCase()),
                    React.createElement("span", { className: "openapi-url" },
                        React.createElement(OpenAPIServerURL, { servers: servers }),
                        path))),
            React.createElement("div", { className: classNames('openapi-columns') },
                React.createElement("div", { className: classNames('openapi-column-spec') },
                    React.createElement(OpenAPISpec, { rawData: toJSON(data), context: clientContext })),
                React.createElement("div", { className: classNames('openapi-column-preview') },
                    React.createElement("div", { className: classNames('openapi-column-preview-body') },
                        React.createElement(OpenAPICodeSample, { ...props }),
                        React.createElement(OpenAPIResponseExample, { ...props })))))));
}
