import * as React from 'react';
import { OpenAPIServerURLVariable } from './OpenAPIServerURLVariable';
/**
 * Show the url of the server with variables replaced by their default values.
 */
export function OpenAPIServerURL(props) {
    const { servers } = props;
    const server = servers[0];
    const parts = parseServerURL(server?.url ?? '');
    return (React.createElement("span", null, parts.map((part, i) => {
        if (part.kind === 'text') {
            return React.createElement("span", { key: i }, part.text);
        }
        else {
            if (!server.variables?.[part.name]) {
                return React.createElement("span", { key: i }, `{${part.name}}`);
            }
            return (React.createElement(OpenAPIServerURLVariable, { key: i, name: part.name, variable: server.variables[part.name] }));
        }
    })));
}
/**
 * Get the default URL for the server.
 */
export function getServersURL(servers) {
    const server = servers[0];
    const parts = parseServerURL(server?.url ?? '');
    return parts
        .map((part) => {
        if (part.kind === 'text') {
            return part.text;
        }
        else {
            return server.variables?.[part.name]?.default ?? `{${part.name}}`;
        }
    })
        .join('');
}
function parseServerURL(url) {
    const parts = url.split(/{([^}]+)}/g);
    const result = [];
    for (let i = 0; i < parts.length; i++) {
        if (i % 2 === 0) {
            result.push({ kind: 'text', text: parts[i] });
        }
        else {
            result.push({ kind: 'variable', name: parts[i] });
        }
    }
    return result;
}
